import { Construct, Resource } from '@aws-cdk/core';
import { IDomainName } from './domain-name';
import { IRestApi } from './restapi';
export interface BasePathMappingOptions {
    /**
     * The base path name that callers of the API must provide in the URL after
     * the domain name (e.g. `example.com/base-path`). If you specify this
     * property, it can't be an empty string.
     *
     * @default - map requests from the domain root (e.g. `example.com`). If this
     * is undefined, no additional mappings will be allowed on this domain name.
     */
    readonly basePath?: string;
}
export interface BasePathMappingProps extends BasePathMappingOptions {
    /**
     * The DomainName to associate with this base path mapping.
     */
    readonly domainName: IDomainName;
    /**
     * The RestApi resource to target.
     */
    readonly restApi: IRestApi;
}
/**
 * This resource creates a base path that clients who call your API must use in
 * the invocation URL.
 *
 * In most cases, you will probably want to use
 * `DomainName.addBasePathMapping()` to define mappings.
 */
export declare class BasePathMapping extends Resource {
    constructor(scope: Construct, id: string, props: BasePathMappingProps);
}
